body
{
	font-family: "Times New Roman", "XTimes", "Times", serif;
	font-size: 12pt;
	line-height: 16pt;
	background-color: white;
	margin-top: 20pt;
	margin-bottom: 20pt;
	margin-left: 50pt;
	margin-right: 50pt;
}

p
{
	margin-top: 0pt;
	margin-bottom: 5pt;
}

div.quotation
{
	margin-top: 16pt;
	margin-bottom: 16pt;
}

div.source
{
	color: #666;
	font-family: "Verdana", "Arial", "XHelvetica", "Helvetica", sans-serif;
	font-size: 10pt;
	line-height: 12pt;
	margin-top: 1pt;
	margin-left: 10pt;
}
div.note
{
	color: #666;
	font-family: "Verdana", "Arial", "XHelvetica", "Helvetica", sans-serif;
	font-size: 8pt;
	line-height: 10pt;
	margin-top: 1pt;
	margin-left: 10pt;
}
h1
{
	font-family: "Arial Narrow", "Arial", "XHelvetica", "Helvetica", sans-serif;
	font-size: 24pt;
	font-weight: normal;
	color: #0050B2;
}
